@@ -539,6 +539,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         given_client: edgedb.AsyncIOClient = None,
         only_one: bool = False,
         merge: bool = True,
+        print_variables: bool = False,
     ) -> T.Union[T.List[NodeType], NodeType]:
         if merge:
             self.merge()
@@ -546,11 +547,13 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         with safe_span(
             op=f"edgedb.query.{self._model_name}", description=query_str[:200]
         ):
+            variables = self._get_nested_query_variables()
             raw_d = await execute_query(
                 client=given_client or self._node.db_client,
                 query_str=query_str,
-                variables=self._get_nested_query_variables(),
+                variables=variables,
                 only_one=only_one,
+                print_variables=print_variables,
             )
         description = len(raw_d) if not only_one else "only-one"
         with safe_span(op=f"parse.{self._model_name}", description=f"{description}"):
